@@ -4,7 +4,8 @@
                   CHOP=FALSE, TIT="", pts=FALSE, forcepix=FALSE,
                   pcex=0.7, SCALE=1, ilocstyle=1,
                   velfile="", stafile="", LOC=NULL,
-                  prefilt=list(fl=.2, fh=15,  type="HP", proto="BU"), filters=NULL, YAX = 1  , xtickfactor = 1  )
+                  prefilt=list(fl=.2, fh=15,  type="HP", proto="BU"), filters=NULL, YAX = 1  ,
+                  xtickfactor = 1 , vertline=NA  )
 {
 
 
@@ -410,7 +411,8 @@ OTHERbuttons = c("NEXT", "PREV","HALF","S1", "S2", "MARK", "DOC", "RESTORE",
     WIN =WIN,
     LASTwin = LASTwin,
     KLICK = NULL,
-    thebuts = FALSE
+    thebuts = FALSE,
+    vertline = vertline
     )
 
 
@@ -424,7 +426,7 @@ OTHERbuttons = c("NEXT", "PREV","HALF","S1", "S2", "MARK", "DOC", "RESTORE",
       YN = PLOT.SEISN(NH, WIN=global.vars$WIN, dt=NH$dt[sel],
         sel=global.vars$sel, sfact=global.vars$ScaleFACT ,
         notes=NH$KNOTES[sel], COL=global.vars$pcols, TIT=global.vars$TIT,
-        SHIFT=global.vars$ASHIFT , pts=global.vars$pts, YAX=global.vars$YAX,   xtickfactor = global.vars$xtickfactor )
+        SHIFT=global.vars$ASHIFT , pts=global.vars$pts, YAX=global.vars$YAX,   xtickfactor = global.vars$xtickfactor, vertline=vertline )
 
       if(!is.na(global.vars$SUBTIT)) title(sub=global.vars$SUBTIT)
 
